/*
 * Copyright (c) 2023 Philippe Proulx <pproulx@efficios.com>
 *
 * SPDX-License-Identifier: MIT
 */

#include "json-val-req.hpp"

namespace bt2c {
namespace internal {

constexpr const char *JsonValOps::objValPropName;

} /* namespace internal */
} /* namespace bt2c */
